@@ -13,7 +13,7 @@ use Fcntl qw(:seek);	   ##-- for rewinding
 use Carp qw(confess);
 use strict;
 
-our $VERSION = '1.22.6';
+our $VERSION = '1.23.0';
 our @ISA = ('PDL::Exporter');
 our @EXPORT_OK =
   (
@@ -188,7 +188,7 @@ sub ccs_readldac {
 
   ##-- get value datatype
   my $type = $opts{type} || $header->{iotype} || $PDL::IO::Misc::deftype;
-  $type    = PDL->can($type)->() if (!ref($type) && PDL->can($type));
+  $type    = PDL->can($type)->() if (defined($type) && !ref($type) && PDL->can($type));
   $type    = $PDL::IO::Misc::deftype if (!ref($type));
 
   ##-- get nnz (per doc)
