@@ -12,7 +12,7 @@ use Fcntl qw(:seek);	   ##-- for rewinding
 use Carp qw(confess);
 use strict;
 
-our $VERSION = '1.22.6';
+our $VERSION = '1.23.0';
 our @ISA = ('PDL::Exporter');
 our @EXPORT_OK =
   (
@@ -176,7 +176,7 @@ sub ccs_rpetsc {
   my $pack_val = $opts{pack_val} // 'd>';
   my $ioblock  = $opts{ioblock}  || 8192;
   my $type     = $opts{type};
-  $type = PDL->can($type)->() if (!ref($type) && PDL->can($type));
+  $type = PDL->can($type)->() if (defined($type) && !ref($type) && PDL->can($type));
   $type = double if (!ref($type));
   $opts{sorted} //= 1;
   $opts{flags}  //= $PDL::CCS::Nd::CCSND_FLAGS_DEFAULT;
@@ -268,8 +268,6 @@ Perl by Larry Wall.
 
 PDL by Karl Glazebrook, Tuomas J. Lukka, Christian Soeller, and others.
 
-LDA-C package by by David M. Blei.
-
 =cut
 
 
