@@ -19,7 +19,7 @@ BEGIN {
   *can = \&UNIVERSAL::can;
 }
 
-our $VERSION = '1.22.6'; ##-- update with perl-reversion from Perl::Version module
+our $VERSION = '1.23.0'; ##-- update with perl-reversion from Perl::Version module
 our @ISA = qw();
 our %EXPORT_TAGS =
   (
@@ -1097,7 +1097,7 @@ sub _ufunc_ind_sub {
     my @dims    = $ccs->dims;
     my ($which0,$which1,$vals1);
     if ($which->dim(0) <= 1) {
-      ##-- flat sum
+      ##-- flat X_ind
       $which0 = $which->slice("(0),");
       $which1 = PDL->zeroes($P_INDX,1,$which->dim(1)); ##-- dummy
       $vals1  = $vals;
@@ -1135,7 +1135,7 @@ sub _ufunc_ind_sub {
 *minimum_ind = _ufunc_ind_sub('minimum_ind', PDL::CCS::Ufunc->can('ccs_accum_minimum_nz_ind'),1);
 
 ##--------------------------------------------------------------
-## Ufuncs: qsort
+## Ufuncs: qsort (from CCS::Functions)
 
 ## ($which0,$nzVals0, $nzix,$nzenum, $whichOut) = $ccs->_qsort()
 ## ($which0,$nzVals0, $nzix,$nzenum, $whichOut) = $ccs->_qsort([o]nzix(NNz), [o]nzenum(Nnz))
@@ -1643,6 +1643,7 @@ foreach my $binop (
 		  )
   {
     eval "*${binop} = *${binop}_mia = _ccsnd_binary_op_mia('${binop}',PDL->can('${binop}'));";
+    die(__PACKAGE__, ": could not define binary operation $binop: $@") if ($@);
   }
 
 *pow = *pow_mia = _ccsnd_binary_op_mia('power',PDL->can('pow'),undef,1);
@@ -1652,7 +1653,9 @@ foreach my $intop (
 		   qw(and2 or2 xor shiftleft shiftright),
 		  )
   {
-    eval "*${intop} = *${intop}_mia = _ccsnd_binary_op_mia('${intop}',PDL->can('${intop}'),\$P_LONG);";
+    my $deftype = PDL->can($intop)->(pdl(0),pdl(0),0)->type->ioname;
+    eval "*${intop} = *${intop}_mia = _ccsnd_binary_op_mia('${intop}',PDL->can('${intop}'),PDL::${deftype}());";
+    die(__PACKAGE__, ": could not define integer operation $intop: $@") if ($@);
   }
 
 ## rassgn_mia($to,$from): binary assignment operation with missing-annihilator assumption
@@ -1812,6 +1815,20 @@ sub matmult2d_zdd  :lvalue {
   return $c;
 }
 
+## $vcos_dense = $a->vcos_zdd($b_dense, ?$vcos_dense, ?$norm_dense)
+##  + assumes $a->missing==0
+sub vcos_zdd {
+  my $a = shift;
+  my $b = shift;
+
+  ##-- ensure $b dense, $a physically indexed ccs
+  $b = todense($b) if ($b->isa(__PACKAGE__));
+  $a = $a->to_physically_indexed();
+
+  ##-- guts
+  return ccs_vcos_zdd($a->_whichND, $a->_nzvals, $b, $a->dim(0), @_);
+}
+
 
 ##--------------------------------------------------------------
 ## Interpolation
